@@ -282,6 +282,10 @@ async function activate(
   // or are unable to use it.
   let hideClusterManager: boolean = false;
 
+  // Whether to test the Dask dashboard using a fetch request or to proceed
+  // with default behavior.
+  let browserDashboardCheck: boolean = false;
+
   // Update the existing trackers and signals in light of a change to the
   // settings system. In particular, this reacts to a change in the setting
   // for auto-starting cluster client.
@@ -343,6 +347,11 @@ async function activate(
         autoStartClient = settings.get('autoStartClient').composite as boolean;
         updateTrackers();
 
+        // Determine whether to validate dashboards via browser check.
+        browserDashboardCheck = settings.get('browserDashboardCheck')
+          .composite as boolean;
+        sidebar.dashboardLauncher.input.browserDashboardCheck = browserDashboardCheck;
+
         //Determine whether to hide the cluster manager
         hideClusterManager = settings.get('hideClusterManager')
           .composite as boolean;
